@@ -11,16 +11,16 @@ class CalibrationsFolder(FilesFolderSyncer):
         self.flats_folders = []
         super().__init__(context, astronomer, folderpath, prefix=prefix)
 
-    def reset(self):
-        super().reset()
-        self.biases_folders = []
-        self.darks_folders = []
-        self.flats_folders = []
-
     def walk(self):
         super().walk()
 
+        known_folderpaths = [f.folderpath for f in self.biases_folders] + \
+                            [f.folderpath for f in self.darks_folders] + \
+                            [f.folderpath for f in self.flats_folders]
+
         for name, path in self._walk_folder():
+            if path in known_folderpaths:
+                continue
             if os.path.isdir(path) and name.lower().startswith('bias'):
                 if self.context.debug or self.context.verbose: print(f' >> Found a {self.prefix} {name} folder.')
                 self.biases_folders.append(FilesFolderSyncer(self.context, self.astronomer, path))
